package me.brianlong.git;

import java.util.Collection;
import java.util.Iterator;
import java.util.LinkedList;
import java.util.List;
import java.util.NoSuchElementException;

public class CompositeIterator<E> implements Iterator<E> {
	
	private final List<Iterator<E>> iterators = new LinkedList<Iterator<E>>();
	private final Iterator<Iterator<E>> iteratorIterators;
	private Iterator<E> iterator;
	
	public CompositeIterator(@SuppressWarnings("unchecked") Collection<E>... cs) {
		for (Collection<E> c : cs)
			if (c != null && !c.isEmpty())
				this.iterators.add(c.iterator());
		this.iteratorIterators = this.iterators.iterator();
	}
	
	@Override
	public boolean hasNext() {
		if (this.iterator == null) {
			if (!this.iteratorIterators.hasNext())
				return false;
			this.iterator = this.iteratorIterators.next();
		}
		
		while (!this.iterator.hasNext() && this.iteratorIterators.hasNext())
			this.iterator = this.iteratorIterators.next();
		return this.iterator.hasNext();
	}
	
	@Override
	public E next() {
		if (!this.hasNext())
			throw new NoSuchElementException();
		return this.iterator.next();
	}

}
