package me.brianlong.git;

import org.eclipse.jgit.api.CloneCommand;
import org.eclipse.jgit.api.FetchCommand;
import org.eclipse.jgit.api.Git;
import org.eclipse.jgit.api.LsRemoteCommand;
import org.eclipse.jgit.api.PullCommand;
import org.eclipse.jgit.api.PushCommand;
import org.eclipse.jgit.api.errors.GitAPIException;
import org.eclipse.jgit.api.errors.InvalidRemoteException;
import org.eclipse.jgit.api.errors.TransportException;
import org.eclipse.jgit.lib.Repository;
import org.eclipse.jgit.transport.CredentialsProvider;

public class CredentialedGit extends ExtendedGit {
	
	private CredentialsProvider credProvider;
	
	public CredentialedGit(CloneCommand clone, CredentialsProvider creds) throws TransportException, InvalidRemoteException, GitAPIException {
		this(clone.setCredentialsProvider(creds).call(), creds);
	}
	
	public CredentialedGit(Git git, CredentialsProvider creds) {
		super(git.getRepository());
		this.credProvider = creds;
	}
	
	public CredentialedGit(Repository repo, CredentialsProvider creds) {
		super(repo);
		this.credProvider = creds;
	}
	
	@Override
	public FetchCommand fetch() {
		return super.fetch().setCredentialsProvider(this.credProvider);
	}
	
	@Override
	public LsRemoteCommand lsRemote() {
		return super.lsRemote().setCredentialsProvider(this.credProvider);
	}
	
	@Override
	public PullCommand pull() {
		return super.pull().setCredentialsProvider(this.credProvider);
	}
	
	@Override
	public PushCommand push() {
		return super.push().setCredentialsProvider(this.credProvider);
	}

}
